@@ -9,6 +9,12 @@ from scipy import stats
 from .RasterBasics import shpClip
 
 def glacierOutline(ones_raster, shape, dest):
+    """
+	Glacier outline
+		ones_raster: input array of ones to clip (array-like)
+		shape: glacier outline shapefline filepath (str) (e.g. 'outline.shp')
+		dest: output filename (str) (e.g. 'output.tif')
+    """
     shpClip(ones_raster, shape, dest, pad_size=0, nan_val=0, fill=True, crop=False)
     return rasterio.open(dest).read(1)
 
@@ -90,8 +96,13 @@ def binPercentile(calcFile, dem, outline, lower_percentile, bin_z=None):
 
 
 def latlonTiffIndex(geotiff, coordinates, crs):
-    # obtain raster array index values at a lat / lon coordinate location
-    # takes in a raster geotiff and tuple of lat lon coordinates
+    """
+	obtain raster array index values at a lat / lon coordinate location
+	takes in a raster geotiff and tuple of lat lon coordinates
+		geotiff: raster filepath (str) (e.g. 'raster.tif')
+	 	coordinates: coordinates at which to sample the raster (tuple)
+		crs: coordiante system of the coordinates (str) (e.g. 'EPSG:4326')
+    """
     geo_array = rasterio.open(geotiff)
     transformer = pyproj.Transformer.from_crs(pyproj.CRS('EPSG:4326'), pyproj.CRS(crs))
     east, north = transformer.transform(coordinates[0], coordinates[1])         # find utm coordinates from lat/lon
